pub struct WizardFileCheck {
pub relative_path: String,
pub found: bool,
pub size_mb: Option<f64>,
}Expand description
One required file and its check result shown in the wizard.
Fields
relative_path: Stringfound: boolsize_mb: Option<f64>Trait Implementations
Sourceimpl Clone for WizardFileCheck
impl Clone for WizardFileCheck
Sourcefn clone(&self) -> WizardFileCheck
fn clone(&self) -> WizardFileCheck
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for WizardFileCheck
impl Debug for WizardFileCheck
Sourceimpl PartialEq for WizardFileCheck
impl PartialEq for WizardFileCheck
Sourcefn eq(&self, other: &WizardFileCheck) -> bool
fn eq(&self, other: &WizardFileCheck) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for WizardFileCheck